@@ -5,7 +5,7 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2024-01-08'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.028'; # VERSION
+our $VERSION = '0.029'; # VERSION
 
 our $schema = ["str" => {
     summary => 'Filesystem file name on a Unix system',
@@ -49,7 +49,7 @@ Sah::Schema::filename::unix - Filesystem file name on a Unix system
 
 =head1 VERSION
 
-This document describes version 0.028 of Sah::Schema::filename::unix (from Perl distribution Sah-Schemas-Path), released on 2024-01-08.
+This document describes version 0.029 of Sah::Schema::filename::unix (from Perl distribution Sah-Schemas-Path), released on 2024-01-08.
 
 =head1 SAH SCHEMA DEFINITION
 
@@ -63,6 +63,8 @@ This document describes version 0.028 of Sah::Schema::filename::unix (from Perl
    },
  ]
 
+Base type: L<str|Data::Sah::Type::str>
+
 Used prefilters: L<Path::expand_tilde|Data::Sah::Filter::perl::Path::expand_tilde>, L<Path::strip_slashes|Data::Sah::Filter::perl::Path::strip_slashes>
 
 Used completion: L<filename|Perinci::Sub::XComplete::filename>
@@ -103,7 +105,7 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
- $data = "";
+ $data = "foo\0";
  my $errmsg = $validator->($data); # => "Must match regex pattern \\A(?:/|/?(?:[^/\\0]{1,255})(?:/[^/\\0]{1,255})*)\\z"
 
 Often a schema has coercion rule or default value rules, so after validation the
@@ -118,8 +120,8 @@ validated value will be different from the original. To return the validated
  my $res = $validator->($data); # => ["","foo/bar"]
  
  # a sample invalid data
- $data = "";
- my $res = $validator->($data); # => ["Must match regex pattern \\A(?:/|/?(?:[^/\\0]{1,255})(?:/[^/\\0]{1,255})*)\\z",""]
+ $data = "foo\0";
+ my $res = $validator->($data); # => ["Must match regex pattern \\A(?:/|/?(?:[^/\\0]{1,255})(?:/[^/\\0]{1,255})*)\\z","foo\0"]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
