@@ -5,7 +5,7 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2024-01-08'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.028'; # VERSION
+our $VERSION = '0.029'; # VERSION
 
 our $schema = [str => {
     summary => 'Filesystem path name',
@@ -58,7 +58,7 @@ Sah::Schema::pathname - Filesystem path name
 
 =head1 VERSION
 
-This document describes version 0.028 of Sah::Schema::pathname (from Perl distribution Sah-Schemas-Path), released on 2024-01-08.
+This document describes version 0.029 of Sah::Schema::pathname (from Perl distribution Sah-Schemas-Path), released on 2024-01-08.
 
 =head1 SAH SCHEMA DEFINITION
 
@@ -75,6 +75,8 @@ This document describes version 0.028 of Sah::Schema::pathname (from Perl distri
    },
  ]
 
+Base type: L<str|Data::Sah::Type::str>
+
 Used prefilters: L<Path::expand_tilde_when_on_unix|Data::Sah::Filter::perl::Path::expand_tilde_when_on_unix>, L<Path::strip_slashes_when_on_unix|Data::Sah::Filter::perl::Path::strip_slashes_when_on_unix>
 
 Used completion: L<filename|Perinci::Sub::XComplete::filename>
@@ -105,7 +107,7 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = "foo";
+ $data = "foo/bar";
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
@@ -120,8 +122,8 @@ validated value will be different from the original. To return the validated
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = "foo";
- my $res = $validator->($data); # => ["","foo"]
+ $data = "foo/bar";
+ my $res = $validator->($data); # => ["","foo/bar"]
  
  # a sample invalid data
  $data = "";
