@@ -5,7 +5,7 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2024-01-08'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.028'; # VERSION
+our $VERSION = '0.029'; # VERSION
 
 our $schema = ["str" => {
     summary => 'Filesystem base path name on a Unix system',
@@ -46,7 +46,7 @@ Sah::Schema::pathname::unix::basename - Filesystem base path name on a Unix syst
 
 =head1 VERSION
 
-This document describes version 0.028 of Sah::Schema::pathname::unix::basename (from Perl distribution Sah-Schemas-Path), released on 2024-01-08.
+This document describes version 0.029 of Sah::Schema::pathname::unix::basename (from Perl distribution Sah-Schemas-Path), released on 2024-01-08.
 
 =head1 SAH SCHEMA DEFINITION
 
@@ -60,6 +60,8 @@ This document describes version 0.028 of Sah::Schema::pathname::unix::basename (
    },
  ]
 
+Base type: L<str|Data::Sah::Type::str>
+
 Used completion: L<pathname_curdir|Perinci::Sub::XComplete::pathname_curdir>
 
 =head1 SYNOPSIS
@@ -92,7 +94,7 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample invalid data
- $data = "/";
+ $data = "";
  my $errmsg = $validator->($data); # => "Must match regex pattern \\A(?:[^/\\0]{1,255})\\z"
 
 Often a schema has coercion rule or default value rules, so after validation the
@@ -103,8 +105,8 @@ validated value will be different from the original. To return the validated
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample invalid data
- $data = "/";
- my $res = $validator->($data); # => ["Must match regex pattern \\A(?:[^/\\0]{1,255})\\z","/"]
+ $data = "";
+ my $res = $validator->($data); # => ["Must match regex pattern \\A(?:[^/\\0]{1,255})\\z",""]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
